FlutterPaymentPluginPlatform class
abstract
- Inheritance
-
- Object
- PlatformInterface
- FlutterPaymentPluginPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
consumeWebReturnIfAny()
→ Future<Map?>
-
Web only: after a top-level WebView payment return, resume and fetch status.
Returns null on native platforms or when there is no pending return.
-
getPlatformVersion()
→ Future<String?>
-
-
logs()
→ Stream<String>
-
Stream of log lines from native (Android/iOS).
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
openPayment({required String url, required Map<String, String> params, String? title, bool javaScript = true, bool devLogs = false, String? actionUrl, String? actionPath, bool forceOverlay = false})
→ Future<Map?>
-
Returns a Map like: { success: bool, data: String?, cancelled: bool }
-
toString()
→ String
-
A string representation of this object.
inherited